@@ -1,10 +1,10 @@
-# $Id: Playlist.pm,v 1.11 2002/12/02 04:23:45 comdog Exp $
+# $Id: Playlist.pm,v 1.14 2004/09/18 16:39:17 comdog Exp $
 package Mac::iTunes::Playlist;
 use strict;
 
 use vars qw($VERSION);
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.11 $ =~ m/ (\d+) \. (\d+) /gx;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.14 $ =~ m/ (\d+) \. (\d+) /gx;
 
 =head1 NAME
 
@@ -21,7 +21,7 @@ Mac::iTunes::Playlist
 
 =head2 METHODS
 
-=over 4 
+=over 4
 
 =item new( TITLE, ARRAYREF )
 
@@ -49,7 +49,7 @@ sub new
 =item new_from_directory( TITLE, DIRECTORY )
 
 Create a playlist from all of the MP3 files in the named
-directory. 
+directory.
 
 =cut
 
@@ -108,11 +108,11 @@ Returns the title of the playlist.
 
 =cut
 
-sub title( [TITLE] )
+sub title
 	{
 	my $self = shift;
 
-	if( @_ ) { $self->{title} = shift }
+	$self->{title} = shift if @_;
 
 	return $self->{title};
 	}
@@ -164,7 +164,7 @@ sub previous_item
 
 Adds the Mac::iTunes::Item object to the playlist.
 
-Returns false or the empty list if the argument is not
+Returns undef or the empty list if the argument is not
 a Mac::iTunes::Item object.
 
 =cut
@@ -343,7 +343,7 @@ sub _not_implemented
 This source is part of a SourceForge project which always has the
 latest sources in CVS, as well as all of the previous releases.
 
-	https://sourceforge.net/projects/brian-d-foy/
+	http://sourceforge.net/projects/brian-d-foy/
 
 If, for some reason, I disappear from the world, one of the other
 members of the project can shepherd this module appropriately.
@@ -358,7 +358,7 @@ L<Mac::iTunes>, L<Mac::iTunes::Item>
 
 =head1 AUTHOR
 
-brian d foy,  E<lt>bdfoy@cpan.orgE<gt>
+brian d foy,  C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT
 
