@@ -1,10 +1,10 @@
-# $Id: Plist.pm,v 1.4 2002/12/02 04:23:45 comdog Exp $
+# $Id: Plist.pm,v 1.5 2004/09/18 16:39:17 comdog Exp $
 package Mac::iTunes::Library::Plist;
 use strict;
 
 use vars qw($VERSION);
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.4 $ =~ m/ (\d+) \. (\d+) /gx;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.5 $ =~ m/ (\d+) \. (\d+) /gx;
 
 =head1 NAME
 
@@ -23,20 +23,20 @@ Someday this will parse the iTunes XML format
 This source is part of a SourceForge project which always has the
 latest sources in CVS, as well as all of the previous releases.
 
-	https://sourceforge.net/projects/brian-d-foy/
+	http://sourceforge.net/projects/brian-d-foy/
 
 If, for some reason, I disappear from the world, one of the other
 members of the project can shepherd this module appropriately.
 
 =head1 AUTHOR
 
-brian d foy, E<lt>bdfoy@cpan.orgE<gt>
+brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT
 
 Copyright 2002, brian d foy, All rights reserved.
 
-You may use this software under the same terms as Perl 
+You may use this software under the same terms as Perl
 itself.
 
 =cut
